Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(126)

Unified Diff: webrtc/base/sslstreamadapter.h

Issue 1269843005: Added DtlsCertificate, a ref counted object owning an SSLIdentity (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Merge with master Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/base/sslstreamadapter.h
diff --git a/webrtc/base/sslstreamadapter.h b/webrtc/base/sslstreamadapter.h
index 4fb238a290482d13d00569bc57ccc5cdc45389f8..4042c22441ae3f65bff0df1cd7a79a784830c04b 100644
--- a/webrtc/base/sslstreamadapter.h
+++ b/webrtc/base/sslstreamadapter.h
@@ -14,6 +14,7 @@
#include <string>
#include <vector>
+#include "talk/app/webrtc/dtlscertificate.h"
#include "webrtc/base/stream.h"
#include "webrtc/base/sslidentity.h"
@@ -64,13 +65,11 @@ class SSLStreamAdapter : public StreamAdapterInterface {
void set_client_auth_enabled(bool enabled) { client_auth_enabled_ = enabled; }
bool client_auth_enabled() const { return client_auth_enabled_; }
- // Specify our SSL identity: key and certificate. Mostly this is
- // only used in the peer-to-peer mode (unless we actually want to
- // provide a client certificate to a server).
- // SSLStream takes ownership of the SSLIdentity object and will
- // free it when appropriate. Should be called no more than once on a
- // given SSLStream instance.
- virtual void SetIdentity(SSLIdentity* identity) = 0;
+ // Specify our DtlsCertificate containing an SSL identity: our key and
+ // SSLCertificate. Mostly this is only used in the peer-to-peer mode (unless
+ // we actually want to provide a client certificate to a server).
+ virtual void SetCertificate(
+ const scoped_refptr<webrtc::DtlsCertificate>& certificate) = 0;
// Call this to indicate that we are to play the server's role in
// the peer-to-peer mode.

Powered by Google App Engine
This is Rietveld 408576698